@@ -1,18 +1,22 @@
 """barcode.base
 
 """
+from typing import ClassVar
+from typing import List
+from typing import Optional
+
+from barcode.writer import BaseWriter
 from barcode.writer import SVGWriter
 
 
 class Barcode:
-
     name = ""
 
     digits = 0
 
     default_writer = SVGWriter
 
-    default_writer_options = {
+    default_writer_options: ClassVar[dict] = {
         "module_width": 0.2,
         "module_height": 15.0,
         "quiet_zone": 6.5,
@@ -24,16 +28,18 @@ class Barcode:
         "text": "",
     }
 
-    def to_ascii(self):
+    writer: BaseWriter
+
+    def to_ascii(self) -> str:
         code = self.build()
         for i, line in enumerate(code):
             code[i] = line.replace("1", "X").replace("0", " ")
         return "\n".join(code)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<{self.__class__.__name__}({self.get_fullcode()!r})>"
 
-    def build(self):
+    def build(self) -> List[str]:
         raise NotImplementedError
 
     def get_fullcode(self):
@@ -44,28 +50,20 @@ class Barcode:
         """
         raise NotImplementedError
 
-    def save(self, filename, options=None, text=None):
+    def save(
+        self, filename: str, options: Optional[dict] = None, text: Optional[str] = None
+    ) -> str:
         """Renders the barcode and saves it in `filename`.
 
-        :parameters:
-            filename : String
-                Filename to save the barcode in (without filename
-                extension).
-            options : Dict
-                The same as in `self.render`.
-            text : str
-                Text to render under the barcode.
+        :param filename: Filename to save the barcode in (without filename extension).
+        :param options: The same as in `self.render`.
+        :param text: Text to render under the barcode.
 
         :returns: The full filename with extension.
-        :rtype: String
         """
-        if text:
-            output = self.render(options, text)
-        else:
-            output = self.render(options)
+        output = self.render(options, text) if text else self.render(options)
 
-        _filename = self.writer.save(filename, output)
-        return _filename
+        return self.writer.save(filename, output)
 
     def write(self, fp, options=None, text=None):
         """Renders the barcode and writes it to the file like object
@@ -82,14 +80,11 @@ class Barcode:
         output = self.render(options, text)
         self.writer.write(output, fp)
 
-    def render(self, writer_options=None, text=None):
+    def render(self, writer_options: Optional[dict] = None, text: Optional[str] = None):
         """Renders the barcode using `self.writer`.
 
-        :parameters:
-            writer_options : Dict
-                Options for `self.writer`, see writer docs for details.
-            text : str
-                Text to render under the barcode.
+        :param writer_options: Options for `self.writer`, see writer docs for details.
+        :param text: Text to render under the barcode.
 
         :returns: Output of the writers render method.
         """
@@ -102,5 +97,4 @@ class Barcode:
                 options["text"] = self.get_fullcode()
         self.writer.set_options(options)
         code = self.build()
-        raw = self.writer.render(code)
-        return raw
+        return self.writer.render(code)
