@@ -2,6 +2,9 @@
 
 :Provided barcodes: Code 39, Code 128, PZN
 """
+
+from typing import Collection
+
 from barcode.base import Barcode
 from barcode.charsets import code39
 from barcode.charsets import code128
@@ -16,7 +19,7 @@ MIN_SIZE = 0.2
 MIN_QUIET_ZONE = 2.54
 
 
-def check_code(code, name, allowed):
+def check_code(code: str, name: str, allowed: Collection[str]) -> None:
     wrong = []
     for char in code:
         if char not in allowed:
@@ -34,7 +37,7 @@ class Code39(Barcode):
 
     name = "Code 39"
 
-    def __init__(self, code: str, writer=None, add_checksum: bool = True):
+    def __init__(self, code: str, writer=None, add_checksum: bool = True) -> None:
         r"""
         :param code: Code 39 string without \* and without checksum.
         :param writer: A ``barcode.writer`` instance used to render the barcode
@@ -48,7 +51,7 @@ class Code39(Barcode):
         self.writer = writer or self.default_writer()
         check_code(self.code, self.name, code39.REF)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.code
 
     def get_fullcode(self) -> str:
@@ -60,6 +63,7 @@ class Code39(Barcode):
         for k, v in code39.MAP.items():
             if check == v[0]:
                 return k
+        return None
 
     def build(self):
         chars = [code39.EDGE]
@@ -88,7 +92,7 @@ class PZN7(Code39):
 
     digits = 6
 
-    def __init__(self, pzn, writer=None):
+    def __init__(self, pzn, writer=None) -> None:
         pzn = pzn[: self.digits]
         if not pzn.isdigit():
             raise IllegalCharacterError("PZN can only contain numbers.")
@@ -108,8 +112,8 @@ class PZN7(Code39):
         checksum = sum_ % 11
         if checksum == 10:
             raise BarcodeError("Checksum can not be 10 for PZN.")
-        else:
-            return checksum
+
+        return checksum
 
 
 class PZN8(PZN7):
@@ -131,14 +135,14 @@ class Code128(Barcode):
 
     name = "Code 128"
 
-    def __init__(self, code, writer=None):
+    def __init__(self, code, writer=None) -> None:
         self.code = code
         self.writer = writer or self.default_writer()
         self._charset = "B"
         self._buffer = ""
         check_code(self.code, self.name, code128.ALL)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.code
 
     @property
@@ -183,31 +187,32 @@ class Code128(Barcode):
         elif self._charset == "B":
             if look_next():
                 codes = self._new_charset("C")
-            elif char not in code128.B:
-                if char in code128.A:
-                    codes = self._new_charset("A")
+            elif char not in code128.B and char in code128.A:
+                codes = self._new_charset("A")
         elif self._charset == "A":
             if look_next():
                 codes = self._new_charset("C")
-            elif char not in code128.A:
-                if char in code128.B:
-                    codes = self._new_charset("B")
+            elif char not in code128.A and char in code128.B:
+                codes = self._new_charset("B")
         return codes
 
     def _convert(self, char):
         if self._charset == "A":
             return code128.A[char]
-        elif self._charset == "B":
+        if self._charset == "B":
             return code128.B[char]
-        elif self._charset == "C":
+        if self._charset == "C":
             if char in code128.C:
                 return code128.C[char]
-            elif char.isdigit():
+            if char.isdigit():
                 self._buffer += char
                 if len(self._buffer) == 2:
                     value = int(self._buffer)
                     self._buffer = ""
                     return value
+                return None
+            return None
+        return None
 
     def _try_to_optimize(self, encoded):
         if encoded[1] in code128.TO:
@@ -232,8 +237,7 @@ class Code128(Barcode):
             encoded.extend(self._new_charset("B"))
             encoded.append(self._convert(self._buffer[0]))
             self._buffer = ""
-        encoded = self._try_to_optimize(encoded)
-        return encoded
+        return self._try_to_optimize(encoded)
 
     def build(self):
         encoded = self._build()
@@ -251,7 +255,7 @@ class Code128(Barcode):
         return super().render(options, text)
 
 
-class Gs1_128(Code128):
+class Gs1_128(Code128):  # noqa: N801
     """
     following the norm, a gs1-128 barcode is a subset of code 128 barcode,
     it can be generated by prepending the code with the FNC1 character
@@ -263,7 +267,7 @@ class Gs1_128(Code128):
 
     FNC1_CHAR = "\xf1"
 
-    def __init__(self, code, writer=None):
+    def __init__(self, code, writer=None) -> None:
         code = self.FNC1_CHAR + code
         super().__init__(code, writer)
 
