@@ -4,19 +4,13 @@
 """
 __docformat__ = "restructuredtext en"
 
+from functools import reduce
+
 from barcode.base import Barcode
 from barcode.charsets import ean as _ean
-from barcode.errors import (
-    IllegalCharacterError,
-    NumberOfDigitsError,
-    WrongCountryCodeError,
-)
-
-# Python 3
-try:
-    reduce
-except NameError:
-    from functools import reduce
+from barcode.errors import IllegalCharacterError
+from barcode.errors import NumberOfDigitsError
+from barcode.errors import WrongCountryCodeError
 
 # EAN13 Specs (all sizes in mm)
 SIZES = {
@@ -47,13 +41,16 @@ class EuropeanArticleNumber13(Barcode):
 
     digits = 12
 
-    def __init__(self, ean, writer=None, no_checksum=False):
+    def __init__(self, ean, writer=None, no_checksum=False, guardbar=False) -> None:
         ean = ean[: self.digits]
         if not ean.isdigit():
             raise IllegalCharacterError("EAN code can only contain numbers.")
         if len(ean) != self.digits:
             raise NumberOfDigitsError(
-                "EAN must have {} digits, not {}.".format(self.digits, len(ean),)
+                "EAN must have {} digits, not {}.".format(
+                    self.digits,
+                    len(ean),
+                )
             )
         self.ean = ean
         # If no checksum
@@ -64,15 +61,23 @@ class EuropeanArticleNumber13(Barcode):
                 ean, ean[self.digits] if len(ean) > self.digits else 0
             )
         else:
-            self.ean = "{}{}".format(ean, self.calculate_checksum())
-        self.writer = writer or Barcode.default_writer()
+            self.ean = f"{ean}{self.calculate_checksum()}"
 
-    def __unicode__(self):
+        self.guardbar = guardbar
+        if guardbar:
+            self.EDGE = _ean.EDGE.replace("1", "G")
+            self.MIDDLE = _ean.MIDDLE.replace("1", "G")
+        else:
+            self.EDGE = _ean.EDGE
+            self.MIDDLE = _ean.MIDDLE
+        self.writer = writer or self.default_writer()
+
+    def __str__(self) -> str:
         return self.ean
 
-    __str__ = __unicode__
-
     def get_fullcode(self):
+        if self.guardbar:
+            return self.ean[0] + " " + self.ean[1:7] + " " + self.ean[7:] + " >"
         return self.ean
 
     def calculate_checksum(self):
@@ -95,14 +100,14 @@ class EuropeanArticleNumber13(Barcode):
         :returns: The pattern as string
         :rtype: String
         """
-        code = _ean.EDGE[:]
+        code = self.EDGE[:]
         pattern = _ean.LEFT_PATTERN[int(self.ean[0])]
         for i, number in enumerate(self.ean[1:7]):
             code += _ean.CODES[pattern[i]][int(number)]
-        code += _ean.MIDDLE
+        code += self.MIDDLE
         for number in self.ean[7:]:
             code += _ean.CODES["C"][int(number)]
-        code += _ean.EDGE
+        code += self.EDGE
         return [code]
 
     def to_ascii(self):
@@ -112,13 +117,20 @@ class EuropeanArticleNumber13(Barcode):
         """
         code = self.build()
         for i, line in enumerate(code):
-            code[i] = line.replace("1", "|").replace("0", " ")
+            code[i] = line.replace("G", "|").replace("1", "|").replace("0", " ")
         return "\n".join(code)
 
     def render(self, writer_options=None, text=None):
         options = {"module_width": SIZES["SC2"]}
         options.update(writer_options or {})
-        return Barcode.render(self, options, text)
+        return super().render(options, text)
+
+
+class EuropeanArticleNumber13WithGuard(EuropeanArticleNumber13):
+    name = "EAN-13 with guards"
+
+    def __init__(self, ean, writer=None, no_checksum=False, guardbar=True) -> None:
+        super().__init__(ean, writer, no_checksum, guardbar)
 
 
 class JapanArticleNumber(EuropeanArticleNumber13):
@@ -135,12 +147,12 @@ class JapanArticleNumber(EuropeanArticleNumber13):
 
     valid_country_codes = list(range(450, 460)) + list(range(490, 500))
 
-    def __init__(self, jan, writer=None):
-        if int(jan[:3]) not in JapanArticleNumber.valid_country_codes:
+    def __init__(self, jan, *args, **kwargs) -> None:
+        if int(jan[:3]) not in self.valid_country_codes:
             raise WrongCountryCodeError(
                 "Country code isn't between 450-460 or 490-500."
             )
-        EuropeanArticleNumber13.__init__(self, jan, writer)
+        super().__init__(jan, *args, **kwargs)
 
 
 class EuropeanArticleNumber8(EuropeanArticleNumber13):
@@ -157,24 +169,33 @@ class EuropeanArticleNumber8(EuropeanArticleNumber13):
 
     digits = 7
 
-    def __init__(self, ean, writer=None):
-        EuropeanArticleNumber13.__init__(self, ean, writer)
-
     def build(self):
         """Builds the barcode pattern from `self.ean`.
 
         :returns: The pattern as string
         :rtype: String
         """
-        code = _ean.EDGE[:]
+        code = self.EDGE[:]
         for number in self.ean[:4]:
             code += _ean.CODES["A"][int(number)]
-        code += _ean.MIDDLE
+        code += self.MIDDLE
         for number in self.ean[4:]:
             code += _ean.CODES["C"][int(number)]
-        code += _ean.EDGE
+        code += self.EDGE
         return [code]
 
+    def get_fullcode(self):
+        if self.guardbar:
+            return "< " + self.ean[:4] + " " + self.ean[4:] + " >"
+        return self.ean
+
+
+class EuropeanArticleNumber8WithGuard(EuropeanArticleNumber8):
+    name = "EAN-8 with guards"
+
+    def __init__(self, ean, writer=None, no_checksum=False, guardbar=True) -> None:
+        super().__init__(ean, writer, no_checksum, guardbar)
+
 
 class EuropeanArticleNumber14(EuropeanArticleNumber13):
     """Represents an EAN-14 barcode. See EAN13's __init__ for details.
@@ -207,5 +228,7 @@ class EuropeanArticleNumber14(EuropeanArticleNumber13):
 # Shortcuts
 EAN14 = EuropeanArticleNumber14
 EAN13 = EuropeanArticleNumber13
+EAN13_GUARD = EuropeanArticleNumber13WithGuard
 EAN8 = EuropeanArticleNumber8
+EAN8_GUARD = EuropeanArticleNumber8WithGuard
 JAN = JapanArticleNumber
