@@ -40,14 +40,13 @@ class InternationalStandardBookNumber13(EuropeanArticleNumber13):
 
     name = "ISBN-13"
 
-    def __init__(self, isbn, writer=None):
+    def __init__(self, isbn, writer=None) -> None:
         isbn = isbn.replace("-", "")
         self.isbn13 = isbn
         if isbn[:3] not in ("978", "979"):
             raise WrongCountryCodeError("ISBN must start with 978 or 979.")
-        if isbn[:3] == "979":
-            if isbn[3:5] not in ("10", "11"):
-                raise BarcodeError("ISBN must start with 97910 or 97911.")
+        if isbn[:3] == "979" and isbn[3:4] not in ("1", "8"):
+            raise BarcodeError("ISBN must start with 97910 or 97911.")
         super().__init__(isbn, writer)
 
 
@@ -66,21 +65,21 @@ class InternationalStandardBookNumber10(InternationalStandardBookNumber13):
 
     digits = 9
 
-    def __init__(self, isbn, writer=None):
+    def __init__(self, isbn, writer=None) -> None:
         isbn = isbn.replace("-", "")
         isbn = isbn[: self.digits]
+        super().__init__("978" + isbn, writer)
         self.isbn10 = isbn
         self.isbn10 = f"{isbn}{self._calculate_checksum()}"
-        super().__init__("978" + isbn, writer)
 
     def _calculate_checksum(self):
         tmp = sum(x * int(y) for x, y in enumerate(self.isbn10[:9], start=1)) % 11
         if tmp == 10:
             return "X"
-        else:
-            return tmp
 
-    def __str__(self):
+        return tmp
+
+    def __str__(self) -> str:
         return self.isbn10
 
 
@@ -99,7 +98,7 @@ class InternationalStandardSerialNumber(EuropeanArticleNumber13):
 
     digits = 7
 
-    def __init__(self, issn, writer=None):
+    def __init__(self, issn, writer=None) -> None:
         issn = issn.replace("-", "")
         issn = issn[: self.digits]
         self.issn = issn
@@ -114,13 +113,13 @@ class InternationalStandardSerialNumber(EuropeanArticleNumber13):
         )
         if tmp == 10:
             return "X"
-        else:
-            return tmp
+
+        return tmp
 
     def make_ean(self):
         return f"977{self.issn[:7]}00{self._calculate_checksum()}"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.issn
 
 
