@@ -8,7 +8,8 @@ from functools import reduce
 
 from barcode.base import Barcode
 from barcode.charsets import upc as _upc
-from barcode.errors import IllegalCharacterError, NumberOfDigitsError
+from barcode.errors import IllegalCharacterError
+from barcode.errors import NumberOfDigitsError
 
 
 class UniversalProductCodeA(Barcode):
@@ -21,7 +22,7 @@ class UniversalProductCodeA(Barcode):
 
     digits = 11
 
-    def __init__(self, upc, writer=None, make_ean=False):
+    def __init__(self, upc, writer=None, make_ean=False) -> None:
         """Initializes new UPC-A barcode.
 
         :param str upc: The upc number as string.
@@ -37,25 +38,23 @@ class UniversalProductCodeA(Barcode):
             raise IllegalCharacterError("UPC code can only contain numbers.")
         if len(upc) != self.digits:
             raise NumberOfDigitsError(
-                "UPC must have {} digits, not {}.".format(self.digits, len(upc))
+                f"UPC must have {self.digits} digits, not {len(upc)}."
             )
         self.upc = upc
-        self.upc = "{}{}".format(upc, self.calculate_checksum())
-        self.writer = writer or Barcode.default_writer()
+        self.upc = f"{upc}{self.calculate_checksum()}"
+        self.writer = writer or self.default_writer()
 
-    def __unicode__(self):
+    def __str__(self) -> str:
         if self.ean:
             return "0" + self.upc
-        else:
-            return self.upc
 
-    __str__ = __unicode__
+        return self.upc
 
     def get_fullcode(self):
         if self.ean:
             return "0" + self.upc
-        else:
-            return self.upc
+
+        return self.upc
 
     def calculate_checksum(self):
         """Calculates the checksum for UPCA/UPC codes
@@ -73,8 +72,8 @@ class UniversalProductCodeA(Barcode):
         check = (evensum + oddsum * 3) % 10
         if check == 0:
             return 0
-        else:
-            return 10 - check
+
+        return 10 - check
 
     def build(self):
         """Builds the barcode pattern from 'self.upc'
@@ -110,7 +109,7 @@ class UniversalProductCodeA(Barcode):
     def render(self, writer_options=None, text=None):
         options = {"module_width": 0.33}
         options.update(writer_options or {})
-        return Barcode.render(self, options, text)
+        return super().render(options, text)
 
 
 UPCA = UniversalProductCodeA
