@@ -5,7 +5,6 @@ from barcode import EAN13
 from barcode.writer import ImageWriter
 from barcode.writer import SVGWriter
 
-
 PATH = os.path.dirname(os.path.abspath(__file__))
 TESTPATH = os.path.join(PATH, "test_outputs")
 
@@ -36,3 +35,11 @@ def test_saving_svg_to_byteio():
 
     with open(f"{TESTPATH}/somefile.svg", "wb") as f:
         EAN13("100000011111", writer=SVGWriter()).write(f)
+
+
+def test_saving_svg_to_byteio_with_guardbar():
+    rv = BytesIO()
+    EAN13(str(100000902922), writer=SVGWriter(), guardbar=True).write(rv)
+
+    with open(f"{TESTPATH}/somefile_guardbar.svg", "wb") as f:
+        EAN13("100000011111", writer=SVGWriter(), guardbar=True).write(f)
